==> nextcloud-15.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files_external/l10n/sq.js <==
OC.L10N.register(
    "files_external",
    {
    "External storages" : "Kujtesë e jashtëme",
    "Personal" : "Personale",
    "System" : "Sistem",
    "Grant access" : "Akordoji hyrje",
    "Error configuring OAuth1" : "Gabim gjatë formësimit të OAuth1",
    "Please provide a valid app key and secret." : "Ju lutemi jepni një kyç dhe një të fshehtë aplikacioni të vlefshme.",
    "Error configuring OAuth2" : "Gabim gjatë formësimit të OAuth2",
    "Generate keys" : "Prodho kyçe",
    "Error generating key pair" : "Gabim gjatë prodhimit të çiftit të kyçeve",
    "All users. Type to select user or group." : "Krejt përdoruesit. Shtypni që të përzgjidhet përdorues ose grup.",
    "(group)" : "(grup)",
    "Compatibility with Mac NFD encoding (slow)" : "Pëerputhshmëri me kodim Mac NFD (e ngadaltë)",
    "Enable encryption" : "Aktivizoni fshehtëzim",
    "Enable previews" : "Aktivizoni paraparje",
    "Enable sharing" : "Aktivizo ndarjet",
    "Check for changes" : "Kontrollo për ndryshime",
    "Never" : "Kurrë",
    "Once every direct access" : "Çdo herë pas hyrjesh të drejtpërdrejta",
    "Delete" : "Fshije",
    "Admin defined" : "Përcaktuar nga përgjegjësi",
    "Saved" : "U ruajt",
    "Saving..." : "Po ruhet …",
    "Save" : "Ruaje",
    "Empty response from the server" : "Përgjigje e zbrazët prej serverit",
    "Couldn't access. Please log out and in again to activate this mount point" : "Nuk mund të ketë akses. Ju lutemi, dilni dhe hyni që të aktivizohet kjo pikë montimi",
    "Couldn't get the information from the remote server: {code} {type}" : "Nuk u morën dot të dhëna nga shërbyesi në largësi: {code} {type}",
    "Couldn't get the list of external mount points: {type}" : "S’u mor dot lista e pikave të jashtme të montimit: {type}",
    "There was an error with message: " : "Pati një gabim me këtë mesazh:",
    "External mount error" : "Gabim i jashtëm montimi",
    "external-storage" : "ruajtje-jashtme",
    "Couldn't fetch list of Windows network drive mount points: Empty response from server" : "S’u mor dot lista e pikave të montimit Windows network drive: përgjigje e zbrazët nga shërbyesi",
    "Some of the configured external mount points are not connected. Please click on the red row(s) for more information" : "Disa nga pikat e jashtme të formësuara të montimit s’janë të lidhura. Ju lutemi, klikoni në shigjetën(at) e kuqe për më tepër të dhëna",
    "Please enter the credentials for the {mount} mount" : "Ju lutemi, jepni kredencialet për pikën e montimit {mount}",
    "Username" : "Emër përdoruesi",
    "Password" : "Fjalëkalim",
    "Credentials saved" : "Kredencialet u ruajtën",
    "Credentials saving failed" : "Ruajtja e kredencialeve dështoi",
    "Credentials required" : "Lypsen kredenciale",
    "Storage with ID \"%d\" not found" : "Ruajtja me ID \"%d\" nuk u gjet",
    "Invalid backend or authentication mechanism class" : "Mekanizëm shërbimi ose klasë mekanizmi mirëfilltësimi e palvefshme",
    "Invalid mount point" : "Pikë montimi e pavlefshme",
    "Objectstore forbidden" : "Objectstore e ndaluar",
    "Invalid storage backend \"%s\"" : "Mekanizëm shërbimi depozite i pavlefshëm \"%s\"",
    "Not permitted to use backend \"%s\"" : "I palejuar të përdorë mekanizmin e shërbimit \"%s\"",
    "Not permitted to use authentication mechanism \"%s\"" : "S’i lejohet të përdorë mekanizmin e mirëfilltësimit \"%s\"",
    "Unsatisfied backend parameters" : "Parametra mekanizmi shërbimi të paplotësuar",
    "Unsatisfied authentication mechanism parameters" : "Parametra mekanizmi mirëfilltësimi të papërmbushur",
    "Insufficient data: %s" : "Të dhëna të pamjaftueshme: %s",
    "%s" : "%s",
    "Storage with ID \"%d\" is not user editable" : "Ruajtja me ID \"%d\" nuk është i editueshëm nga përdorues",
    "Access key" : "Kyç hyrjesh",
    "Secret key" : "Kyç i fshehtë",
    "Builtin" : "I brendshëm",
    "None" : "Asnjë",
    "OAuth1" : "OAuth1",
    "App key" : "Kyç aplikacioni",
    "App secret" : "E fshehtë aplikacioni",
    "OAuth2" : "OAuth2",
    "Client ID" : "ID klienti",
    "Client secret" : "E fshehtë klienti",
    "Tenant name" : "Emër qiraxhiu",
    "Identity endpoint URL" : "Identifiko pikëmbarimin URL",
    "Domain" : "Përkatësi",
    "Rackspace" : "Rackspace",
    "API key" : "Kyç API",
    "Global credentials" : "Kredenciale globale",
    "Log-in credentials, save in database" : "Kredencialet e identifikimit, ruaji në bazën e të dhënave",
    "Username and password" : "Emër përdoruesi dhe fjalëkalim",
    "Log-in credentials, save in session" : "Kredenciale hyrjesh, ruaji për sesion",
    "User entered, store in database" : "Përdoruesi u identifikua, ruaj në bazë të dhënash",
    "RSA public key" : "Kyç publik RSA ",
    "Public key" : "Kyç publik",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Bucket",
    "Hostname" : "Strehëemër",
    "Port" : "Portë",
    "Region" : "Rajon",
    "Enable SSL" : "Aktivizo SSL-në",
    "Enable Path Style" : "Aktivizo Stile Shtegu",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Nëndosje e largët",
    "Secure https://" : "https:// e sigurt",
    "FTP" : "FTP",
    "Host" : "Strehë",
    "Secure ftps://" : "ftps:// e sigurt",
    "Local" : "Vendore",
    "Location" : "Vendndodhje",
    "Nextcloud" : "Nextcloud",
    "SFTP" : "SFTP",
    "Root" : "Rrënjë",
    "SFTP with secret key login" : "SFTP me hyrje me kyç të fshehtë",
    "SMB / CIFS" : "SMB / CIFS",
    "Share" : "Ndajeni me të tjerët",
    "SMB / CIFS using OC login" : "SMB / CIFS me përdorim hyrjeje OC",
    "Username as share" : "Emër përdoruesi si emër ndarjeje",
    "OpenStack Object Storage" : "Depozitë OpenStack Object",
    "Service name" : "Emër shërbimi",
    "Request timeout (seconds)" : "Kohë skadimi kërkese (sekonda)",
    "The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "Mbështetja e cURL në PHP nuk është e instaluar ose e aktivizuar. Lidhja e %s nuk është e mundur. Ju lutemi kërkojini administratorin të sistemit tuaj që ta instaloj.",
    "The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "Mbështetja e FTP në PHP nuk është e aktivizuar ose instaluar.Lidhja e %s nuk është e mundur.Ju lutem kërkojini administratorit të sistemit tuaj që ta instalojë.",
    "Name" : "Emër",
    "Storage type" : "Lloj depozite",
    "Scope" : "Shtrirje",
    "Folder name" : "Emër dosjeje",
    "External storage" : "Depozitë e jashtme",
    "Authentication" : "Mirëfilltësim",
    "Configuration" : "Formësim",
    "Available for" : "E gatshme për",
    "Add storage" : "Shtoni depozitë",
    "Advanced settings" : "Rregullime të mëtejshme",
    "Allow users to mount external storage" : "Lejoju përdoruesve të montojnë depozita të jashtme",
    "OpenStack" : "OpenStack",
    "\"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "\"%s\" nuk është instaluar.Montimi i %s nuk është i mundur.Ju lutem kërkojini administratorit të sistemit tuaj ta instalojë.",
    "Allow users to mount the following external storage" : "Lejoju përdoruesve të montojnë depozitën e jashtme vijuese"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-18.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files_external/l10n/sq.js <==
OC.L10N.register(
    "files_external",
    {
    "External storages" : "Kujtesë e jashtëme",
    "Personal" : "Personale",
    "System" : "Sistem",
    "Grant access" : "Akordoji hyrje",
    "Error configuring OAuth1" : "Gabim gjatë formësimit të OAuth1",
    "Please provide a valid app key and secret." : "Ju lutemi jepni një kyç dhe një të fshehtë aplikacioni të vlefshme.",
    "Error configuring OAuth2" : "Gabim gjatë formësimit të OAuth2",
    "Generate keys" : "Prodho kyçe",
    "Error generating key pair" : "Gabim gjatë prodhimit të çiftit të kyçeve",
    "All users. Type to select user or group." : "Krejt përdoruesit. Shtypni që të përzgjidhet përdorues ose grup.",
    "(group)" : "(grup)",
    "Compatibility with Mac NFD encoding (slow)" : "Pëerputhshmëri me kodim Mac NFD (e ngadaltë)",
    "Enable encryption" : "Aktivizoni fshehtëzim",
    "Enable previews" : "Aktivizoni paraparje",
    "Enable sharing" : "Aktivizo ndarjet",
    "Check for changes" : "Kontrollo për ndryshime",
    "Never" : "Kurrë",
    "Once every direct access" : "Çdo herë pas hyrjesh të drejtpërdrejta",
    "Read only" : "Vetëm i lexueshëm",
    "Delete" : "Fshije",
    "Admin defined" : "Përcaktuar nga përgjegjësi",
    "Saved" : "U ruajt",
    "Saving..." : "Po ruhet …",
    "Save" : "Ruaje",
    "Empty response from the server" : "Përgjigje e zbrazët prej serverit",
    "Couldn't access. Please log out and in again to activate this mount point" : "Nuk mund të ketë akses. Ju lutemi, dilni dhe hyni që të aktivizohet kjo pikë montimi",
    "Couldn't get the information from the remote server: {code} {type}" : "Nuk u morën dot të dhëna nga shërbyesi në largësi: {code} {type}",
    "Couldn't get the list of external mount points: {type}" : "S’u mor dot lista e pikave të jashtme të montimit: {type}",
    "There was an error with message: " : "Pati një gabim me këtë mesazh:",
    "External mount error" : "Gabim i jashtëm montimi",
    "external-storage" : "ruajtje-jashtme",
    "Couldn't fetch list of Windows network drive mount points: Empty response from server" : "S’u mor dot lista e pikave të montimit Windows network drive: përgjigje e zbrazët nga shërbyesi",
    "Please enter the credentials for the {mount} mount" : "Ju lutemi, jepni kredencialet për pikën e montimit {mount}",
    "Username" : "Emër përdoruesi",
    "Password" : "Fjalëkalim",
    "Credentials saved" : "Kredencialet u ruajtën",
    "Credentials saving failed" : "Ruajtja e kredencialeve dështoi",
    "Credentials required" : "Lypsen kredenciale",
    "Storage with ID \"%d\" not found" : "Ruajtja me ID \"%d\" nuk u gjet",
    "Invalid backend or authentication mechanism class" : "Mekanizëm shërbimi ose klasë mekanizmi mirëfilltësimi e palvefshme",
    "Invalid mount point" : "Pikë montimi e pavlefshme",
    "Objectstore forbidden" : "Objectstore e ndaluar",
    "Invalid storage backend \"%s\"" : "Mekanizëm shërbimi depozite i pavlefshëm \"%s\"",
    "Not permitted to use backend \"%s\"" : "I palejuar të përdorë mekanizmin e shërbimit \"%s\"",
    "Not permitted to use authentication mechanism \"%s\"" : "S’i lejohet të përdorë mekanizmin e mirëfilltësimit \"%s\"",
    "Unsatisfied backend parameters" : "Parametra mekanizmi shërbimi të paplotësuar",
    "Unsatisfied authentication mechanism parameters" : "Parametra mekanizmi mirëfilltësimi të papërmbushur",
    "Insufficient data: %s" : "Të dhëna të pamjaftueshme: %s",
    "%s" : "%s",
    "Storage with ID \"%d\" is not user editable" : "Ruajtja me ID \"%d\" nuk është i editueshëm nga përdorues",
    "Access key" : "Kyç hyrjesh",
    "Secret key" : "Kyç i fshehtë",
    "Builtin" : "I brendshëm",
    "None" : "Asnjë",
    "OAuth1" : "OAuth1",
    "App key" : "Kyç aplikacioni",
    "App secret" : "E fshehtë aplikacioni",
    "OAuth2" : "OAuth2",
    "Client ID" : "ID klienti",
    "Client secret" : "E fshehtë klienti",
    "Tenant name" : "Emër qiraxhiu",
    "Identity endpoint URL" : "Identifiko pikëmbarimin URL",
    "Domain" : "Përkatësi",
    "Rackspace" : "Rackspace",
    "API key" : "Kyç API",
    "Global credentials" : "Kredenciale globale",
    "Log-in credentials, save in database" : "Kredencialet e identifikimit, ruaji në bazën e të dhënave",
    "Username and password" : "Emër përdoruesi dhe fjalëkalim",
    "Log-in credentials, save in session" : "Kredenciale hyrjesh, ruaji për sesion",
    "User entered, store in database" : "Përdoruesi u identifikua, ruaj në bazë të dhënash",
    "RSA public key" : "Kyç publik RSA ",
    "Public key" : "Kyç publik",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Bucket",
    "Hostname" : "Strehëemër",
    "Port" : "Portë",
    "Region" : "Rajon",
    "Enable SSL" : "Aktivizo SSL-në",
    "Enable Path Style" : "Aktivizo Stile Shtegu",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Nëndosje e largët",
    "Secure https://" : "https:// e sigurt",
    "FTP" : "FTP",
    "Host" : "Strehë",
    "Secure ftps://" : "ftps:// e sigurt",
    "Local" : "Vendore",
    "Location" : "Vendndodhje",
    "Nextcloud" : "Nextcloud",
    "SFTP" : "SFTP",
    "Root" : "Rrënjë",
    "SFTP with secret key login" : "SFTP me hyrje me kyç të fshehtë",
    "SMB / CIFS" : "SMB / CIFS",
    "Share" : "Ndajeni me të tjerët",
    "Show hidden files" : "Shfaq skedarët e fshehur",
    "SMB / CIFS using OC login" : "SMB / CIFS me përdorim hyrjeje OC",
    "Username as share" : "Emër përdoruesi si emër ndarjeje",
    "OpenStack Object Storage" : "Depozitë OpenStack Object",
    "Service name" : "Emër shërbimi",
    "Request timeout (seconds)" : "Kohë skadimi kërkese (sekonda)",
    "The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "Mbështetja e cURL në PHP nuk është e instaluar ose e aktivizuar. Lidhja e %s nuk është e mundur. Ju lutemi kërkojini administratorin të sistemit tuaj që ta instaloj.",
    "The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "Mbështetja e FTP në PHP nuk është e aktivizuar ose instaluar.Lidhja e %s nuk është e mundur.Ju lutem kërkojini administratorit të sistemit tuaj që ta instalojë.",
    "External storage support" : "Suport i kujtesë së jashtme",
    "Name" : "Emër",
    "Storage type" : "Lloj depozite",
    "Scope" : "Shtrirje",
    "Open documentation" : "Dokumentacion i hapur",
    "Folder name" : "Emër dosjeje",
    "External storage" : "Depozitë e jashtme",
    "Authentication" : "Mirëfilltësim",
    "Configuration" : "Formësim",
    "Available for" : "E gatshme për",
    "Add storage" : "Shtoni depozitë",
    "Advanced settings" : "Rregullime të mëtejshme",
    "Allow users to mount external storage" : "Lejoju përdoruesve të montojnë depozita të jashtme"
},
"nplurals=2; plural=(n != 1);");
